@@ -68,6 +68,15 @@ def main():
     
     config=LoadConfig()
     
+    if(data.Ysize==120): #workaround for wrong defaults
+        data.Ysize=121
+        data.Yscale=1
+        data.trigger=30  
+        config.set('main', 'Ysize', str(data.Ysize))      
+        config.set('main', 'Yscale', str(data.Yscale))      
+        print "changed default parameters for Yscale and Ysize"
+    
+    
     data.app_path=os.path.dirname(__file__)
     if(data.app_path==""): data.app_path="./"
     else: data.app_path=data.app_path+"/"
@@ -596,7 +605,8 @@ class frmViewWindow(QMainWindow):
 
 
     def UpdateScreen(self):
-        shortfolder=string.replace(data.logfolder, data.homedir, "~")
+        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
+        shortfolder=string.replace(data.logfolder, "//", "/") #workaround
         self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
 #        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
 #        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
